Package: mixtools
Version: 2.0.0.1
Date: 2022-12-04
Title: Tools for Analyzing Finite Mixture Models
Authors@R: c(person("Derek", "Young", role = c("aut", "cre"),
	email = "derek.young@uky.edu", comment = c(ORCID = "0000-0002-3048-3803")),
	person("Tatiana", "Benaglia", role = "aut"),
	person("Didier", "Chauveau", role = "aut"),
	person("David", "Hunter", role = "aut"),
	person("Kedai", "Cheng", role = "aut"),
	person("Ryan", "Elmore", role = "ctb"),
	person("Thomas", "Hettmansperger", role = "ctb"),
	person("Hoben", "Thomas", role = "ctb"),
	person("Fengjuan", "Xuan", role = "ctb"))
Depends: R (>= 4.0.0)
Imports: kernlab, MASS, plotly, scales, segmented, stats, survival
URL: https://github.com/dsy109/mixtools
Description: Analyzes finite mixture models for various parametric and semiparametric settings.  This includes mixtures of parametric distributions (normal, multivariate normal, multinomial, gamma), various Reliability Mixture Models (RMMs), mixtures-of-regressions settings (linear regression, logistic regression, Poisson regression, linear regression with changepoints, predictor-dependent mixing proportions, random effects regressions, hierarchical mixtures-of-experts), and tools for selecting the number of components (bootstrapping the likelihood ratio test statistic, mixturegrams, and model selection criteria).  Bayesian estimation of mixtures-of-linear-regressions models is available as well as a novel data depth method for obtaining credible bands.  This package is based upon work supported by the National Science Foundation under Grant No. SES-0518772 and the Chan Zuckerberg Initiative: Essential Open Source Software for Science (Grant No. 2020-255193).
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2025-03-08 07:39:45 UTC; hornik
Author: Derek Young [aut, cre] (<https://orcid.org/0000-0002-3048-3803>),
  Tatiana Benaglia [aut],
  Didier Chauveau [aut],
  David Hunter [aut],
  Kedai Cheng [aut],
  Ryan Elmore [ctb],
  Thomas Hettmansperger [ctb],
  Hoben Thomas [ctb],
  Fengjuan Xuan [ctb]
Maintainer: Derek Young <derek.young@uky.edu>
Repository: CRAN
Date/Publication: 2025-03-08 08:58:50 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 16:34:20 UTC; unix
Archs: mixtools.so.dSYM
